@@ -38,11 +38,13 @@ class Message:
         self.name = dictionary['name']
         # The specific message ID
         self.id = dictionary['id']
-
         # The type, which must always be 'Message' or 'Indication'
         self.type = dictionary['type']
-        # The version info, optional
-        self.version_info = dictionary['version'].split('.') if 'version' in dictionary else []
+
+        # The message version info is no longer supported
+        if 'version' in dictionary:
+            raise ValueError('The "version" tag is no longer supported')
+
         self.static = True if 'scope' in dictionary and dictionary['scope'] == 'library-only' else False
         self.abort = True if 'abort' in dictionary and dictionary['abort'] == 'yes' else False
 
@@ -66,6 +68,9 @@ class Message:
         # Create the ID enumeration name
         self.id_enum_name = utils.build_underscore_name(self.fullname).upper()
 
+        # Create the build symbol name
+        self.build_symbol = 'HAVE_' + self.id_enum_name
+
         # Build output container.
         # Every defined message will have its own output container, which
         # will generate a new Output type and public getters for each output
@@ -112,7 +117,7 @@ class Message:
             '    %s,\n'
             '    GError **error)\n'
             '{\n'
-            '    QmiMessage *self;\n'
+            '    g_autoptr(QmiMessage) self = NULL;\n'
             '\n'
             '    self = qmi_message_new (QMI_SERVICE_${service},\n'
             '                            cid,\n'
@@ -134,7 +139,7 @@ class Message:
                     '\n'
                     '    /* All TLVs are optional, we allow NULL input */\n'
                     '    if (!input)\n'
-                    '        return self;\n')
+                    '        return g_steal_pointer (&self);\n')
             else:
                 # If we do have mandatory fields, issue error if no input
                 # given.
@@ -146,7 +151,7 @@ class Message:
                     '                     QMI_CORE_ERROR,\n'
                     '                     QMI_CORE_ERROR_INVALID_ARGS,\n'
                     '                     "Message \'${name}\' has mandatory TLVs");\n'
-                    '        goto error_out;\n'
+                    '        return NULL;\n'
                     '    }\n')
                 cfile.write(string.Template(template).substitute(translations))
 
@@ -170,21 +175,14 @@ class Message:
                         '                     QMI_CORE_ERROR,\n'
                         '                     QMI_CORE_ERROR_INVALID_ARGS,\n'
                         '                     "Missing mandatory TLV \'${tlv_name}\' in message \'${name}\'");\n'
-                        '        goto error_out;\n')
+                        '        return NULL;\n')
                     cfile.write(string.Template(template).substitute(translations))
 
                 cfile.write(
                     '    }\n')
         cfile.write(
             '\n'
-            '    return self;\n')
-        if self.input.fields:
-            cfile.write(
-                '\n'
-                'error_out:\n'
-                '    qmi_message_unref (self);\n'
-                '    return NULL;\n')
-        cfile.write(
+            '    return g_steal_pointer (&self);\n'
             '}\n')
 
 
@@ -278,7 +276,7 @@ class Message:
                 '    struct ${type}_${underscore}_context *ctx)\n'
                 '{\n'
                 '    const gchar *tlv_type_str = NULL;\n'
-                '    gchar *translated_value;\n'
+                '    g_autofree gchar *translated_value = NULL;\n'
                 '\n')
 
             if self.type == 'Message':
@@ -330,7 +328,7 @@ class Message:
                 '    }\n'
                 '\n'
                 '    if (!tlv_type_str) {\n'
-                '        gchar *value_str = NULL;\n'
+                '        g_autofree gchar *value_str = NULL;\n'
                 '\n'
                 '        value_str = qmi_message_get_tlv_printable (ctx->self,\n'
                 '                                                   ctx->line_prefix,\n'
@@ -338,9 +336,8 @@ class Message:
                 '                                                   value,\n'
                 '                                                   length);\n'
                 '        g_string_append (ctx->printable, value_str);\n'
-                '        g_free (value_str);\n'
                 '    } else {\n'
-                '        gchar *value_hex;\n'
+                '        g_autofree gchar *value_hex = NULL;\n'
                 '\n'
                 '        value_hex = __qmi_utils_str_hex (value, length, \':\');\n'
                 '        g_string_append_printf (ctx->printable,\n'
@@ -354,8 +351,6 @@ class Message:
                 '                                ctx->line_prefix, length,\n'
                 '                                ctx->line_prefix, value_hex,\n'
                 '                                ctx->line_prefix, translated_value ? translated_value : "");\n'
-                '        g_free (value_hex);\n'
-                '        g_free (translated_value);\n'
                 '    }\n'
                 '}\n')
 
@@ -427,6 +422,7 @@ class Message:
                          'camelcase'           : utils.build_camelcase_name (self.fullname),
                          'service'             : utils.build_underscore_name (self.service),
                          'name_underscore'     : utils.build_underscore_name (self.name),
+                         'build_symbol'        : self.build_symbol,
                          'fullname'            : self.service + ' ' + self.name,
                          'type'                : 'response' if self.type == 'Message' else 'indication' }
 
@@ -461,6 +457,7 @@ class Message:
             '${public_types}'
             '${public_methods}'
             '<SUBSECTION Private>\n'
+            '${build_symbol}\n'
             '${private}'
             '<SUBSECTION Standard>\n'
             '${standard}'
