@@ -53,6 +53,8 @@ class VariableInteger(Variable):
             self.private_format = self.format
             self.public_format = dictionary['public-format'] if 'public-format' in dictionary else self.private_format
 
+        self.element_type = self.public_format
+
     """
     Read a single integer from the raw byte buffer
     """
@@ -137,14 +139,14 @@ class VariableInteger(Variable):
                 '${lp}/* Write the ${len}-byte long variable to the buffer */\n'
                 '${lp}if (!qmi_message_tlv_write_sized_guint (self, ${len},${endian} ${variable_name}, error)) {\n'
                 '${lp}    g_prefix_error (error, "Cannot write sized integer in TLV \'${tlv_name}\': ");\n'
-                '${lp}    goto error_out;\n'
+                '${lp}    return NULL;\n'
                 '${lp}}\n')
         elif self.private_format == self.public_format:
             template = (
                 '${lp}/* Write the ${private_format} variable to the buffer */\n'
                 '${lp}if (!qmi_message_tlv_write_${private_format} (self,${endian} ${variable_name}, error)) {\n'
                 '${lp}    g_prefix_error (error, "Cannot write integer in TLV \'${tlv_name}\': ");\n'
-                '${lp}    goto error_out;\n'
+                '${lp}    return NULL;\n'
                 '${lp}}\n')
         else:
             template = (
@@ -155,7 +157,7 @@ class VariableInteger(Variable):
                 '${lp}    /* Write the ${private_format} variable to the buffer */\n'
                 '${lp}    if (!qmi_message_tlv_write_${private_format} (self,${endian} tmp, error)) {\n'
                 '${lp}        g_prefix_error (error, "Cannot write enum in TLV \'${tlv_name}\': ");\n'
-                '${lp}        goto error_out;\n'
+                '${lp}        return NULL;\n'
                 '${lp}    }\n'
                 '${lp}}\n')
         f.write(string.Template(template).substitute(translations))
@@ -187,7 +189,8 @@ class VariableInteger(Variable):
         elif self.private_format == 'gint64':
             common_format = '%" G_GINT64_FORMAT "'
         elif self.private_format in ('gfloat', 'gdouble'):
-            common_format = '%f'
+            common_format = '%lf'
+            common_cast = '(gdouble)'
 
         translations = { 'lp'             : line_prefix,
                          'private_format' : self.private_format,
@@ -231,11 +234,10 @@ class VariableInteger(Variable):
                 '${lp}    g_string_append_printf (printable, "%s", ${public_type_underscore}_get_string ((${public_format})tmp));\n'
                 '#elif defined  __${public_type_underscore_upper}_IS_FLAGS__\n'
                 '${lp}    {\n'
-                '${lp}        gchar *flags_str;\n'
+                '${lp}        g_autofree gchar *flags_str = NULL;\n'
                 '\n'
                 '${lp}        flags_str = ${public_type_underscore}_build_string_from_mask ((${public_format})tmp);\n'
                 '${lp}        g_string_append_printf (printable, "%s", flags_str);\n'
-                '${lp}        g_free (flags_str);\n'
                 '${lp}    }\n'
                 '#else\n'
                 '# error unexpected public format: ${public_format}\n'
@@ -296,7 +298,7 @@ class VariableInteger(Variable):
                          'name'          : variable_name }
 
         template = (
-            '${lp}@${name}: a placeholder for the output #${public_format}, or %NULL if not required.\n')
+            '${lp}@${name}: (out): a placeholder for the output #${public_format}, or %NULL if not required.\n')
         return string.Template(template).substitute(translations)
 
     """
