@@ -37,6 +37,7 @@ class VariableString(Variable):
 
         self.private_format = 'gchar *'
         self.public_format = self.private_format
+        self.element_type = 'utf8'
 
         if 'fixed-size' in dictionary:
             self.is_fixed_size = True
@@ -123,7 +124,7 @@ class VariableString(Variable):
         template = (
             '${lp}if (!qmi_message_tlv_write_string (self, ${n_size_prefix_bytes}, ${variable_name}, ${fixed_size}, error)) {\n'
             '${lp}    g_prefix_error (error, "Cannot write string in TLV \'${tlv_name}\': ");\n'
-            '${lp}    goto error_out;\n'
+            '${lp}    return NULL;\n'
             '${lp}}\n')
 
         f.write(string.Template(template).substitute(translations))
@@ -154,12 +155,11 @@ class VariableString(Variable):
             template = (
                 '\n'
                 '${lp}{\n'
-                '${lp}    gchar *tmp;\n'
+                '${lp}    g_autofree gchar *tmp = NULL;\n'
                 '\n'
                 '${lp}    if (!qmi_message_tlv_read_string (message, init_offset, &offset, ${n_size_prefix_bytes}, ${max_size}, &tmp, &error))\n'
                 '${lp}        goto out;\n'
                 '${lp}    g_string_append (printable, tmp);\n'
-                '${lp}    g_free (tmp);\n'
                 '${lp}}\n')
 
         f.write(string.Template(template).substitute(translations))
@@ -214,7 +214,7 @@ class VariableString(Variable):
                          'name' : variable_name }
 
         template = (
-            '${lp}@${name}: a placeholder for the output constant string, or %NULL if not required.\n')
+            '${lp}@${name}: (out): a placeholder for the output constant string, or %NULL if not required.\n')
         return string.Template(template).substitute(translations)
 
 
