@@ -84,9 +84,19 @@
 #include "qmi-enums-gas.h"
 #include "qmi-gas.h"
 
+#include "qmi-gms.h"
+
+#include "qmi-enums-dsd.h"
+#include "qmi-flags64-dsd.h"
+#include "qmi-dsd.h"
+
 /* generated */
 #include "qmi-error-types.h"
 #include "qmi-enum-types.h"
 #include "qmi-flags64-types.h"
 
+#if QMI_QRTR_SUPPORTED
+# include <libqrtr-glib.h>
+#endif
+
 #endif /* _LIBQMI_GLIB_H_ */
