@@ -34,6 +34,11 @@
 #include "qmi-message.h"
 #include "qmi-message-context.h"
 #include "qmi-client.h"
+#include "qmi-version.h"
+
+#if QMI_QRTR_SUPPORTED
+# include <libqrtr-glib.h>
+#endif
 
 G_BEGIN_DECLS
 
@@ -133,6 +138,7 @@ struct _QmiDeviceClass {
 };
 
 GType qmi_device_get_type (void);
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (QmiDevice, g_object_unref)
 
 /**
  * qmi_device_new:
@@ -159,7 +165,7 @@ void qmi_device_new (GFile               *file,
  *
  * Finishes an operation started with qmi_device_new().
  *
- * Returns: A newly created #QmiDevice, or %NULL if @error is set.
+ * Returns: (transfer full): A newly created #QmiDevice, or %NULL if @error is set.
  *
  * Since: 1.0
  */
@@ -172,7 +178,7 @@ QmiDevice *qmi_device_new_finish (GAsyncResult  *res,
  *
  * Get the #GFile associated with this #QmiDevice.
  *
- * Returns: a #GFile that must be freed with g_object_unref().
+ * Returns: (transfer full): a #GFile that must be freed with g_object_unref().
  *
  * Since: 1.0
  */
@@ -185,7 +191,7 @@ GFile *qmi_device_get_file (QmiDevice *self);
  * Get the #GFile associated with this #QmiDevice, without increasing the reference count
  * on the returned object.
  *
- * Returns: a #GFile. Do not free the returned object, it is owned by @self.
+ * Returns: (transfer none): a #GFile. Do not free the returned object, it is owned by @self.
  *
  * Since: 1.0
  */
@@ -258,7 +264,7 @@ gboolean qmi_device_is_open (QmiDevice *self);
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DEVICE_OPEN_FLAGS_NONE               = 0,
     QMI_DEVICE_OPEN_FLAGS_VERSION_INFO       = 1 << 0,
     QMI_DEVICE_OPEN_FLAGS_SYNC               = 1 << 1,
@@ -272,12 +278,6 @@ typedef enum {
     QMI_DEVICE_OPEN_FLAGS_EXPECT_INDICATIONS = 1 << 9,
 } QmiDeviceOpenFlags;
 
-/**
- * qmi_device_open_flags_build_string_from_mask:
- *
- * Since: 1.0
- */
-
 /**
  * qmi_device_open:
  * @self: a #QmiDevice.
@@ -399,7 +399,7 @@ void qmi_device_allocate_client (QmiDevice           *self,
  *
  * Finishes an operation started with qmi_device_allocate_client().
  *
- * Returns: a newly allocated #QmiClient, or %NULL if @error is set.
+ * Returns: (transfer full): a newly allocated #QmiClient, or %NULL if @error is set.
  *
  * Since: 1.0
  */
@@ -416,17 +416,11 @@ QmiClient *qmi_device_allocate_client_finish (QmiDevice     *self,
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DEVICE_RELEASE_CLIENT_FLAGS_NONE        = 0,
     QMI_DEVICE_RELEASE_CLIENT_FLAGS_RELEASE_CID = 1 << 0
 } QmiDeviceReleaseClientFlags;
 
-/**
- * qmi_device_release_client_flags_build_string_from_mask:
- *
- * Since: 1.0
- */
-
 /**
  * qmi_device_release_client:
  * @self: a #QmiDevice.
@@ -516,57 +510,6 @@ gboolean qmi_device_set_instance_id_finish (QmiDevice     *self,
                                             guint16       *link_id,
                                             GError       **error);
 
-/**
- * qmi_device_command:
- * @self: a #QmiDevice.
- * @message: the message to send.
- * @timeout: maximum time, in seconds, to wait for the response.
- * @cancellable: a #GCancellable, or %NULL.
- * @callback: a #GAsyncReadyCallback to call when the operation is finished.
- * @user_data: the data to pass to callback function.
- *
- * Asynchronously sends a generic #QmiMessage to the device with no context.
- *
- * If the operation is cancelled via @cancellable, a %QMI_PROTOCOL_ERROR_ABORTED
- * error will be returned always. If the QMI method may be aborted, there is
- * no guarantee that the operation is truly aborted before the error is returned
- * so it may really happen that the operation really succeeded and the method
- * would still return %QMI_PROTOCOL_ERROR_ABORTED. In order to use abortable
- * methods and make sure the response is the correct one, use
- * qmi_device_command_abortable().
- *
- * When the operation is finished @callback will be called. You can then call
- * qmi_device_command_finish() to get the result of the operation.
- *
- * Since: 1.0
- * Deprecated: 1.18: Use qmi_device_command_full() instead.
- */
-G_DEPRECATED_FOR (qmi_device_command_full)
-void qmi_device_command (QmiDevice           *self,
-                         QmiMessage          *message,
-                         guint                timeout,
-                         GCancellable        *cancellable,
-                         GAsyncReadyCallback  callback,
-                         gpointer             user_data);
-
-/**
- * qmi_device_command_finish:
- * @self: a #QmiDevice.
- * @res: a #GAsyncResult.
- * @error: Return location for error or %NULL.
- *
- * Finishes an operation started with qmi_device_command().
- *
- * Returns: a #QmiMessage response, or %NULL if @error is set. The returned value should be freed with qmi_message_unref().
- *
- * Since: 1.0
- * Deprecated: 1.18. Use qmi_device_command_full_finish() instead.
- */
-G_DEPRECATED_FOR (qmi_device_command_full_finish)
-QmiMessage  *qmi_device_command_finish (QmiDevice     *self,
-                                        GAsyncResult  *res,
-                                        GError       **error);
-
 /**
  * qmi_device_command_full:
  * @self: a #QmiDevice.
@@ -611,7 +554,7 @@ void qmi_device_command_full (QmiDevice           *self,
  *
  * Finishes an operation started with qmi_device_command_full().
  *
- * Returns: a #QmiMessage response, or %NULL if @error is set. The returned value should be freed with qmi_message_unref().
+ * Returns: (transfer full): a #QmiMessage response, or %NULL if @error is set. The returned value should be freed with qmi_message_unref().
  *
  * Since: 1.18
  */
@@ -665,10 +608,10 @@ typedef gboolean (* QmiDeviceCommandAbortableParseResponseFn) (QmiDevice   *self
  * @message: the message to send.
  * @message_context: the context of the message.
  * @timeout: maximum time, in seconds, to wait for the response.
- * @abort_build_request_fn: callback to build an abort request.
- * @abort_parse_response_fn: callback to parse an abort response.
- * @abort_user_data: user data to pass to @build_request_fn and @parse_response_fn.
- * @abort_user_data_free: a #GDestroyNotify to free @abort_user_data.
+ * @abort_build_request_fn: (scope async): callback to build an abort request.
+ * @abort_parse_response_fn: (scope async): callback to parse an abort response.
+ * @abort_user_data: (closure): user data to pass to @build_request_fn and @parse_response_fn.
+ * @abort_user_data_free: (destroy abort_user_data): a #GDestroyNotify to free @abort_user_data.
  * @cancellable: a #GCancellable, or %NULL.
  * @callback: a #GAsyncReadyCallback to call when the operation is finished.
  * @user_data: the data to pass to callback function.
@@ -727,7 +670,7 @@ void qmi_device_command_abortable (QmiDevice                                *sel
  *
  * Finishes an operation started with qmi_device_command_abortable().
  *
- * Returns: a #QmiMessage response, or %NULL if @error is set. The returned value should be freed with qmi_message_unref().
+ * Returns: (transfer full): a #QmiMessage response, or %NULL if @error is set. The returned value should be freed with qmi_message_unref().
  *
  * Since: 1.24
  */
@@ -781,7 +724,9 @@ void qmi_device_get_service_version_info (QmiDevice           *self,
  *
  * Finishes an operation started with qmi_device_get_service_version_info().
  *
- * Returns: a #GArray of #QmiDeviceServiceVersionInfo elements, or %NULL if @error is set. The returned value should be freed with g_array_unref().
+ * Returns: (transfer full)(element-type QmiDeviceServiceVersionInfo):
+ *  a #GArray of #QmiDeviceServiceVersionInfo elements, or %NULL if @error
+ *  is set. The returned value should be freed with g_array_unref().
  *
  * Since: 1.6
  */
@@ -798,18 +743,12 @@ GArray *qmi_device_get_service_version_info_finish (QmiDevice     *self,
  *
  * Since: 1.14
  */
-typedef enum {
+typedef enum { /*< since=1.14 >*/
     QMI_DEVICE_EXPECTED_DATA_FORMAT_UNKNOWN,
     QMI_DEVICE_EXPECTED_DATA_FORMAT_802_3,
     QMI_DEVICE_EXPECTED_DATA_FORMAT_RAW_IP,
 } QmiDeviceExpectedDataFormat;
 
-/**
- * qmi_device_expected_data_format_get_string:
- *
- * Since: 1.14
- */
-
 /**
  * qmi_device_get_expected_data_format:
  * @self: a #QmiDevice.
@@ -845,6 +784,51 @@ gboolean qmi_device_set_expected_data_format (QmiDevice                    *self
                                               QmiDeviceExpectedDataFormat   format,
                                               GError                      **error);
 
+
+/******************************************************************************/
+/* New QRTR based APIs */
+
+#if QMI_QRTR_SUPPORTED
+
+/**
+ * QMI_DEVICE_NODE:
+ *
+ * Symbol defining the #QmiDevice:device-node property.
+ */
+#define QMI_DEVICE_NODE "device-node"
+
+/**
+ * qmi_device_new_from_node:
+ * @node: a #QrtrNode.
+ * @cancellable: optional #GCancellable object, #NULL to ignore.
+ * @callback: a #GAsyncReadyCallback to call when the initialization is finished.
+ * @user_data: the data to pass to callback function.
+ *
+ * Asynchronously creates a #QmiDevice object to manage @node.
+ * When the operation is finished, @callback will be invoked. You can then call
+ * qmi_device_new_finish() to get the result of the operation.
+ *
+ * Only available if libqmi was compiled with QRTR support.
+ */
+void qmi_device_new_from_node (QrtrNode            *node,
+                               GCancellable        *cancellable,
+                               GAsyncReadyCallback  callback,
+                               gpointer             user_data);
+
+/**
+ * qmi_device_new_from_node_finish:
+ * @res: a #GAsyncResult.
+ * @error: Return location for error or %NULL.
+ *
+ * Finishes an operation started with qmi_device_new_from_node().
+ *
+ * Returns: (transfer full): A newly created #QmiDevice, or %NULL if @error is set.
+ */
+QmiDevice *qmi_device_new_from_node_finish (GAsyncResult  *res,
+                                            GError       **error);
+
+#endif /* QMI_QRTR_SUPPORTED */
+
 G_END_DECLS
 
 #endif /* _LIBQMI_GLIB_QMI_DEVICE_H_ */
