@@ -30,7 +30,6 @@
 
 /**
  * SECTION: qmi-enums-loc
- * @title: LOC enumerations and flags
  *
  * This section defines enumerations and flags used in the LOC service
  * interface.
@@ -49,18 +48,12 @@
  *
  * Since: 1.20
  */
-typedef enum {
+typedef enum { /*< since=1.20 >*/
     QMI_LOC_INTERMEDIATE_REPORT_STATE_UNKNOWN = 0,
     QMI_LOC_INTERMEDIATE_REPORT_STATE_ENABLE  = 1,
     QMI_LOC_INTERMEDIATE_REPORT_STATE_DISABLE = 2,
 } QmiLocIntermediateReportState;
 
-/**
- * qmi_loc_intermediate_report_state_get_string:
- *
- * Since: 1.20
- */
-
 /**
  * QmiLocIndicationStatus:
  * @QMI_LOC_INDICATION_STATUS_SUCCESS: Success.
@@ -75,7 +68,7 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_INDICATION_STATUS_SUCCESS            = 0,
     QMI_LOC_INDICATION_STATUS_GENERAL_FAILURE    = 1,
     QMI_LOC_INDICATION_STATUS_UNSUPPORTED        = 2,
@@ -85,12 +78,6 @@ typedef enum {
     QMI_LOC_INDICATION_STATUS_TIMEOUT            = 6,
 } QmiLocIndicationStatus;
 
-/**
- * qmi_loc_indication_status_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocSessionStatus:
  * @QMI_LOC_SESSION_STATUS_SUCCESS: Success
@@ -106,7 +93,7 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_SESSION_STATUS_SUCCESS         = 0,
     QMI_LOC_SESSION_STATUS_IN_PROGRESS     = 1,
     QMI_LOC_SESSION_STATUS_GENERAL_FAILURE = 2,
@@ -117,12 +104,6 @@ typedef enum {
     QMI_LOC_SESSION_STATUS_ENGINE_LOCKED   = 6,
 } QmiLocSessionStatus;
 
-/**
- * qmi_loc_session_status_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocFixRecurrenceType:
  * @QMI_LOC_FIX_RECURRENCE_TYPE_REQUEST_PERIODIC_FIXES: Periodic fixes.
@@ -132,17 +113,11 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_FIX_RECURRENCE_TYPE_REQUEST_PERIODIC_FIXES = 1,
     QMI_LOC_FIX_RECURRENCE_TYPE_REQUEST_SINGLE_FIX     = 2,
 } QmiLocFixRecurrenceType;
 
-/**
- * qmi_loc_fix_recurrence_type_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocOperationMode:
  * @QMI_LOC_OPERATION_MODE_DEFAULT: Default.
@@ -156,7 +131,7 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_OPERATION_MODE_DEFAULT    = 1,
     QMI_LOC_OPERATION_MODE_MSB        = 2,
     QMI_LOC_OPERATION_MODE_MSA        = 3,
@@ -165,12 +140,6 @@ typedef enum {
     QMI_LOC_OPERATION_MODE_WWAN       = 6,
 } QmiLocOperationMode;
 
-/**
- * qmi_loc_operation_mode_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocEngineState:
  * @QMI_LOC_ENGINE_STATE_ON: On.
@@ -180,17 +149,11 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_ENGINE_STATE_ON  = 1,
     QMI_LOC_ENGINE_STATE_OFF = 2,
 } QmiLocEngineState;
 
-/**
- * qmi_loc_engine_state_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocTechnologyUsed:
  * @QMI_LOC_TECHNOLOGY_USED_SATELLITE: Satellite.
@@ -206,7 +169,7 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_TECHNOLOGY_USED_SATELLITE          = 1 << 0,
     QMI_LOC_TECHNOLOGY_USED_CELLULAR           = 1 << 1,
     QMI_LOC_TECHNOLOGY_USED_WIFI               = 1 << 2,
@@ -217,12 +180,6 @@ typedef enum {
     QMI_LOC_TECHNOLOGY_USED_HYBRID             = 1 << 7,
 } QmiLocTechnologyUsed;
 
-/**
- * qmi_loc_technology_used_build_string_from_mask
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocReliability:
  * @QMI_LOC_RELIABILITY_NOT_SET: Not set.
@@ -235,7 +192,7 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_RELIABILITY_NOT_SET  = 0,
     QMI_LOC_RELIABILITY_VERY_LOW = 1,
     QMI_LOC_RELIABILITY_LOW      = 2,
@@ -243,12 +200,6 @@ typedef enum {
     QMI_LOC_RELIABILITY_HIGH     = 4,
 } QmiLocReliability;
 
-/**
- * qmi_loc_reliability_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocTimeSource:
  * @QMI_LOC_TIME_SOURCE_INVALID: Invalid.
@@ -273,7 +224,7 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_TIME_SOURCE_INVALID                =  0,
     QMI_LOC_TIME_SOURCE_NETWORK_TIME_TRANSFER  =  1,
     QMI_LOC_TIME_SOURCE_NETWORK_TIME_TAGGING   =  2,
@@ -293,12 +244,6 @@ typedef enum {
     QMI_LOC_TIME_SOURCE_BDS_TOW_DECODE         = 16,
 } QmiLocTimeSource;
 
-/**
- * qmi_loc_time_source_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocSatelliteValidInformation:
  * @QMI_LOC_SATELLITE_VALID_INFORMATION_SYSTEM: System,
@@ -314,7 +259,7 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_SATELLITE_VALID_INFORMATION_SYSTEM                = 1 << 0,
     QMI_LOC_SATELLITE_VALID_INFORMATION_GNSS_SATELLITE_ID     = 1 << 1,
     QMI_LOC_SATELLITE_VALID_INFORMATION_HEALTH_STATUS         = 1 << 2,
@@ -325,12 +270,6 @@ typedef enum {
     QMI_LOC_SATELLITE_VALID_INFORMATION_SIGNAL_TO_NOISE_RATIO = 1 << 7,
 } QmiLocSatelliteValidInformation;
 
-/**
- * qmi_loc_satellite_valid_information_build_string_from_mask
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocSystem:
  * @QMI_LOC_SYSTEM_GPS: GPS.
@@ -343,7 +282,7 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_SYSTEM_GPS     = 1,
     QMI_LOC_SYSTEM_GALILEO = 2,
     QMI_LOC_SYSTEM_SBAS    = 3,
@@ -351,12 +290,6 @@ typedef enum {
     QMI_LOC_SYSTEM_GLONASS = 5,
 } QmiLocSystem;
 
-/**
- * qmi_loc_system_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocHealthStatus:
  * @QMI_LOC_HEALTH_STATUS_UNHEALTHY: Unhealthy.
@@ -366,17 +299,11 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_HEALTH_STATUS_UNHEALTHY = 0,
     QMI_LOC_HEALTH_STATUS_HEALTHY   = 1,
 } QmiLocHealthStatus;
 
-/**
- * qmi_loc_health_status_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocNavigationData:
  * @QMI_LOC_NAVIGATION_DATA_HAS_EPHEMERIS: Has ephemeris.
@@ -386,17 +313,11 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_NAVIGATION_DATA_HAS_EPHEMERIS = 0,
     QMI_LOC_NAVIGATION_DATA_HAS_ALMANAC   = 1,
 } QmiLocNavigationData;
 
-/**
- * qmi_loc_navigation_data_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocSatelliteStatus:
  * @QMI_LOC_SATELLITE_STATUS_IDLE: Idle.
@@ -407,18 +328,12 @@ typedef enum {
  *
  * Since 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_SATELLITE_STATUS_IDLE      = 0,
     QMI_LOC_SATELLITE_STATUS_SEARCHING = 1,
     QMI_LOC_SATELLITE_STATUS_TRACKING  = 2,
 } QmiLocSatelliteStatus;
 
-/**
- * qmi_loc_satellite_status_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocServerType:
  * @QMI_LOC_SERVER_TYPE_UNKNOWN: Unknown.
@@ -431,7 +346,7 @@ typedef enum {
  *
  * Since: 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_SERVER_TYPE_UNKNOWN    = 0,
     QMI_LOC_SERVER_TYPE_CDMA_PDE   = 1,
     QMI_LOC_SERVER_TYPE_CDMA_MPC   = 2,
@@ -439,12 +354,6 @@ typedef enum {
     QMI_LOC_SERVER_TYPE_CUSTOM_PDE = 4,
 } QmiLocServerType;
 
-/**
- * qmi_loc_server_type_get_string
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocServerAddressType:
  * @QMI_LOC_SERVER_ADDRESS_TYPE_NONE: None.
@@ -453,35 +362,27 @@ typedef enum {
  * @QMI_LOC_SERVER_ADDRESS_TYPE_URL: URL server address.
  *
  * Type of server address for Assisted-GPS.
+ *
+ * Since: 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_SERVER_ADDRESS_TYPE_NONE = 0,
     QMI_LOC_SERVER_ADDRESS_TYPE_IPV4 = 1 << 0,
     QMI_LOC_SERVER_ADDRESS_TYPE_IPV6 = 1 << 1,
     QMI_LOC_SERVER_ADDRESS_TYPE_URL  = 1 << 2,
 } QmiLocServerAddressType;
 
-/**
- * qmi_loc_server_address_type_build_string_from_mask
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocPredictedOrbitsDataFormat:
  * @QMI_LOC_PREDICTED_ORBITS_DATA_FORMAT_XTRA: Qualcomm XTRA database.
  *
  * Type of predicted orbits data.
- */
-typedef enum {
-    QMI_LOC_PREDICTED_ORBITS_DATA_FORMAT_XTRA = 0
-} QmiLocPredictedOrbitsDataFormat;
-
-/**
- * qmi_loc_predicted_orbits_data_format_get_string
  *
  * Since: 1.22
  */
+typedef enum { /*< since=1.22 >*/
+    QMI_LOC_PREDICTED_ORBITS_DATA_FORMAT_XTRA = 0
+} QmiLocPredictedOrbitsDataFormat;
 
 /**
  * QmiLocDeleteSvInfo:
@@ -489,17 +390,13 @@ typedef enum {
  * @QMI_LOC_DELETE_SV_INFO_ALMANAC: Almanac.
  *
  * Type of data to delete for a given satellite.
- */
-typedef enum {
-    QMI_LOC_DELETE_SV_INFO_EPHEMERIS = 1 << 0,
-    QMI_LOC_DELETE_SV_INFO_ALMANAC   = 1 << 1,
-} QmiLocDeleteSvInfo;
-
-/**
- * qmi_loc_delete_sv_info_build_string_from_mask
  *
  * Since: 1.22
  */
+typedef enum { /*< since=1.22 >*/
+    QMI_LOC_DELETE_SV_INFO_EPHEMERIS = 1 << 0,
+    QMI_LOC_DELETE_SV_INFO_ALMANAC   = 1 << 1,
+} QmiLocDeleteSvInfo;
 
 /**
  * QmiLocDeleteCellDatabase:
@@ -515,8 +412,10 @@ typedef enum {
  * @QMI_LOC_DELETE_CELL_DATABASE_NEIGHBOR_INFO: Neighboring cell info.
  *
  * Type of data to delete from the cell database.
+ *
+ * Since: 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_DELETE_CELL_DATABASE_POS            = 1 << 0,
     QMI_LOC_DELETE_CELL_DATABASE_LATEST_GPS_POS = 1 << 1,
     QMI_LOC_DELETE_CELL_DATABASE_OTA_POS        = 1 << 2,
@@ -529,12 +428,6 @@ typedef enum {
     QMI_LOC_DELETE_CELL_DATABASE_NEIGHBOR_INFO  = 1 << 9,
 } QmiLocDeleteCellDatabase;
 
-/**
- * qmi_loc_delete_cell_database_build_string_from_mask
- *
- * Since: 1.22
- */
-
 /**
  * QmiLocDeleteClockInfo:
  * @QMI_LOC_DELETE_CLOCK_INFO_TIME_EST: Time estimation.
@@ -550,8 +443,10 @@ typedef enum {
  * @QMI_LOC_DELETE_CLOCK_INFO_DISABLE_TT: Disable TT.
  *
  * Type of data to delete from the clock information.
+ *
+ * Since: 1.22
  */
-typedef enum {
+typedef enum { /*< since=1.22 >*/
     QMI_LOC_DELETE_CLOCK_INFO_TIME_EST         = 1 << 0,
     QMI_LOC_DELETE_CLOCK_INFO_FREQ_EST         = 1 << 1,
     QMI_LOC_DELETE_CLOCK_INFO_WEEK_NUMBER      = 1 << 2,
@@ -566,9 +461,29 @@ typedef enum {
 } QmiLocDeleteClockInfo;
 
 /**
- * qmi_loc_delete_clock_info_build_string_from_mask
+ * QmiLocNmeaType:
+ * @QMI_LOC_NMEA_TYPE_GGA: Enable GGA traces.
+ * @QMI_LOC_NMEA_TYPE_RMC: Enable RMC traces.
+ * @QMI_LOC_NMEA_TYPE_GSV: Enable GSV traces.
+ * @QMI_LOC_NMEA_TYPE_GSA: Enable GSA traces.
+ * @QMI_LOC_NMEA_TYPE_VTG: Enable VTG traces.
+ * @QMI_LOC_NMEA_TYPE_PQXFI: Enable PQXFI traces.
+ * @QMI_LOC_NMEA_TYPE_PSTIS: Enable PSTIS traces.
+ * @QMI_LOC_NMEA_TYPE_ALL: Enable all supported trace types.
  *
- * Since: 1.22
+ * NMEA trace types that may be enabled in the GNSS engine.
+ *
+ * Since: 1.26
  */
+typedef enum { /*< since=1.26 >*/
+    QMI_LOC_NMEA_TYPE_GGA   = 1 << 0,
+    QMI_LOC_NMEA_TYPE_RMC   = 1 << 1,
+    QMI_LOC_NMEA_TYPE_GSV   = 1 << 2,
+    QMI_LOC_NMEA_TYPE_GSA   = 1 << 3,
+    QMI_LOC_NMEA_TYPE_VTG   = 1 << 4,
+    QMI_LOC_NMEA_TYPE_PQXFI = 1 << 5,
+    QMI_LOC_NMEA_TYPE_PSTIS = 1 << 6,
+    QMI_LOC_NMEA_TYPE_ALL   = 0x0000FFFF,
+} QmiLocNmeaType;
 
 #endif /* _LIBQMI_GLIB_QMI_ENUMS_LOC_H_ */
