@@ -30,7 +30,6 @@
 
 /**
  * SECTION: qmi-enums-uim
- * @title: UIM enumerations and flags
  *
  * This section defines enumerations and flags used in the UIM service
  * interface.
@@ -44,23 +43,19 @@
  * @QMI_UIM_EVENT_REGISTRATION_FLAG_CARD_STATUS: Card status.
  * @QMI_UIM_EVENT_REGISTRATION_FLAG_SAP_CONNECTION: SAP connection.
  * @QMI_UIM_EVENT_REGISTRATION_FLAG_EXTENDED_CARD_STATUS: Extended card status.
+ * @QMI_UIM_EVENT_REGISTRATION_FLAG_PHYSICAL_SLOT_STATUS: Physical slot status. Since 1.26.
  *
  * Flags to use to register to UIM indications.
  *
  * Since: 1.22.4
  */
-typedef enum {
+typedef enum { /*< since=1.22.4 >*/
     QMI_UIM_EVENT_REGISTRATION_FLAG_CARD_STATUS          = 1 << 0,
     QMI_UIM_EVENT_REGISTRATION_FLAG_SAP_CONNECTION       = 1 << 1,
     QMI_UIM_EVENT_REGISTRATION_FLAG_EXTENDED_CARD_STATUS = 1 << 2,
+    QMI_UIM_EVENT_REGISTRATION_FLAG_PHYSICAL_SLOT_STATUS = 1 << 4,
 } QmiUimEventRegistrationFlag;
 
-/**
- * qmi_uim_event_registration_flag_build_string_from_mask:
- *
- * Since: 1.22.4
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI UIM Read Record' request/response */
 
@@ -81,7 +76,7 @@ typedef enum {
  *
  * Since: 1.6
  */
-typedef enum {
+typedef enum { /*< since=1.6 >*/
     QMI_UIM_SESSION_TYPE_PRIMARY_GW_PROVISIONING   = 0,
     QMI_UIM_SESSION_TYPE_PRIMARY_1X_PROVISIONING   = 1,
     QMI_UIM_SESSION_TYPE_SECONDARY_GW_PROVISIONING = 2,
@@ -94,12 +89,6 @@ typedef enum {
     QMI_UIM_SESSION_TYPE_LOGICAL_CHANNEL_SLOT_2    = 9
 } QmiUimSessionType;
 
-/**
- * qmi_uim_session_type_get_string:
- *
- * Since: 1.6
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI UIM Get File Attributes' request/response */
 
@@ -115,7 +104,7 @@ typedef enum {
  *
  * Since: 1.6
  */
-typedef enum {
+typedef enum { /*< since=1.6 >*/
     QMI_UIM_FILE_TYPE_TRANSPARENT    = 0,
     QMI_UIM_FILE_TYPE_CYCLIC         = 1,
     QMI_UIM_FILE_TYPE_LINEAR_FIXED   = 2,
@@ -123,12 +112,6 @@ typedef enum {
     QMI_UIM_FILE_TYPE_MASTER_FILE    = 4
 } QmiUimFileType;
 
-/**
- * qmi_uim_file_type_get_string:
- *
- * Since: 1.6
- */
-
 /**
  * QmiUimSecurityAttributeLogic:
  * @QMI_UIM_SECURITY_ATTRIBUTE_LOGIC_ALWAYS: Always.
@@ -141,7 +124,7 @@ typedef enum {
  *
  * Since: 1.6
  */
-typedef enum {
+typedef enum { /*< since=1.6 >*/
     QMI_UIM_SECURITY_ATTRIBUTE_LOGIC_ALWAYS = 0,
     QMI_UIM_SECURITY_ATTRIBUTE_LOGIC_NEVER  = 1,
     QMI_UIM_SECURITY_ATTRIBUTE_LOGIC_AND    = 2,
@@ -149,12 +132,6 @@ typedef enum {
     QMI_UIM_SECURITY_ATTRIBUTE_LOGIC_SINGLE = 4
 } QmiUimSecurityAttributeLogic;
 
-/**
- * qmi_uim_security_attribute_logic_get_string:
- *
- * Since: 1.6
- */
-
 /**
  * QmiUimSecurityAttribute:
  * @QMI_UIM_SECURITY_ATTRIBUTE_PIN1: PIN1.
@@ -166,19 +143,13 @@ typedef enum {
  *
  * Since: 1.6
  */
-typedef enum {
+typedef enum { /*< since=1.6 >*/
     QMI_UIM_SECURITY_ATTRIBUTE_PIN1 = 1 << 0,
     QMI_UIM_SECURITY_ATTRIBUTE_PIN2 = 1 << 1,
     QMI_UIM_SECURITY_ATTRIBUTE_UPIN = 1 << 2,
     QMI_UIM_SECURITY_ATTRIBUTE_ADM  = 1 << 3
 } QmiUimSecurityAttribute;
 
-/**
- * qmi_uim_security_attribute_build_string_from_mask:
- *
- * Since: 1.6
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI UIM Set PIN Protection' */
 
@@ -194,7 +165,7 @@ typedef enum {
  *
  * Since: 1.14
  */
-typedef enum {
+typedef enum { /*< since=1.14 >*/
     QMI_UIM_PIN_ID_UNKNOWN    = 0,
     QMI_UIM_PIN_ID_PIN1       = 1,
     QMI_UIM_PIN_ID_PIN2       = 2,
@@ -202,12 +173,6 @@ typedef enum {
     QMI_UIM_PIN_ID_HIDDEN_KEY = 4
 } QmiUimPinId;
 
-/**
- * qmi_uim_pin_id_get_string:
- *
- * Since: 1.14
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI UIM Get Card Status' request/response */
 
@@ -221,18 +186,12 @@ typedef enum {
  *
  * Since: 1.10
  */
-typedef enum {
+typedef enum { /*< since=1.10 >*/
     QMI_UIM_CARD_STATE_ABSENT  = 0,
     QMI_UIM_CARD_STATE_PRESENT = 1,
     QMI_UIM_CARD_STATE_ERROR   = 2
 } QmiUimCardState;
 
-/**
- * qmi_uim_card_state_get_string:
- *
- * Since: 1.10
- */
-
 /**
  * QmiUimPinState:
  * @QMI_UIM_PIN_STATE_NOT_INITIALIZED: Not initialized.
@@ -246,7 +205,7 @@ typedef enum {
  *
  * Since: 1.10
  */
-typedef enum {
+typedef enum { /*< since=1.10 >*/
     QMI_UIM_PIN_STATE_NOT_INITIALIZED      = 0,
     QMI_UIM_PIN_STATE_ENABLED_NOT_VERIFIED = 1,
     QMI_UIM_PIN_STATE_ENABLED_VERIFIED     = 2,
@@ -255,12 +214,6 @@ typedef enum {
     QMI_UIM_PIN_STATE_PERMANENTLY_BLOCKED  = 5,
 } QmiUimPinState;
 
-/**
- * qmi_uim_pin_state_get_string:
- *
- * Since: 1.10
- */
-
 /**
  * QmiUimCardError:
  * @QMI_UIM_CARD_ERROR_UNKNOWN: Unknown error.
@@ -276,7 +229,7 @@ typedef enum {
  *
  * Since: 1.10
  */
-typedef enum {
+typedef enum { /*< since=1.10 >*/
     QMI_UIM_CARD_ERROR_UNKNOWN          = 0,
     QMI_UIM_CARD_ERROR_POWER_DOWN       = 1,
     QMI_UIM_CARD_ERROR_POLL             = 2,
@@ -287,12 +240,6 @@ typedef enum {
     QMI_UIM_CARD_ERROR_TECHNICAL        = 7
 } QmiUimCardError;
 
-/**
- * qmi_uim_card_error_get_string:
- *
- * Since: 1.10
- */
-
 /**
  * QmiUimCardApplicationType:
  * @QMI_UIM_CARD_APPLICATION_TYPE_UNKNOWN: Unknown.
@@ -306,7 +253,7 @@ typedef enum {
  *
  * Since: 1.10
  */
-typedef enum {
+typedef enum { /*< since=1.10 >*/
     QMI_UIM_CARD_APPLICATION_TYPE_UNKNOWN = 0,
     QMI_UIM_CARD_APPLICATION_TYPE_SIM     = 1,
     QMI_UIM_CARD_APPLICATION_TYPE_USIM    = 2,
@@ -315,12 +262,6 @@ typedef enum {
     QMI_UIM_CARD_APPLICATION_TYPE_ISIM    = 5,
 } QmiUimCardApplicationType;
 
-/**
- * qmi_uim_card_application_type_get_string:
- *
- * Since: 1.10
- */
-
 /**
  * QmiUimCardApplicationState:
  * @QMI_UIM_CARD_APPLICATION_STATE_UNKNOWN: Unknown.
@@ -336,7 +277,7 @@ typedef enum {
  *
  * Since: 1.10
  */
-typedef enum {
+typedef enum { /*< since=1.10 >*/
     QMI_UIM_CARD_APPLICATION_STATE_UNKNOWN                     = 0,
     QMI_UIM_CARD_APPLICATION_STATE_DETECTED                    = 1,
     QMI_UIM_CARD_APPLICATION_STATE_PIN1_OR_UPIN_PIN_REQUIRED   = 2,
@@ -347,12 +288,6 @@ typedef enum {
     QMI_UIM_CARD_APPLICATION_STATE_READY                       = 7,
 } QmiUimCardApplicationState;
 
-/**
- * qmi_uim_card_application_state_get_string:
- *
- * Since: 1.10
- */
-
 /**
  * QmiUimCardApplicationPersonalizationState:
  * @QMI_UIM_CARD_APPLICATION_PERSONALIZATION_STATE_UNKNOWN: Unknown.
@@ -366,7 +301,7 @@ typedef enum {
  *
  * Since: 1.10
  */
-typedef enum {
+typedef enum { /*< since=1.10 >*/
     QMI_UIM_CARD_APPLICATION_PERSONALIZATION_STATE_UNKNOWN             = 0,
     QMI_UIM_CARD_APPLICATION_PERSONALIZATION_STATE_IN_PROGRESS         = 1,
     QMI_UIM_CARD_APPLICATION_PERSONALIZATION_STATE_READY               = 2,
@@ -375,12 +310,6 @@ typedef enum {
     QMI_UIM_CARD_APPLICATION_PERSONALIZATION_STATE_PERMANENTLY_BLOCKED = 5,
 } QmiUimCardApplicationPersonalizationState;
 
-/**
- * qmi_uim_card_application_personalization_state_get_string:
- *
- * Since: 1.10
- */
-
 /**
  * QmiUimCardApplicationPersonalizationFeature:
  * @QMI_UIM_CARD_APPLICATION_PERSONALIZATION_FEATURE_GW_NETWORK: GW network.
@@ -400,7 +329,7 @@ typedef enum {
  *
  * Since: 1.10
  */
-typedef enum {
+typedef enum { /*< since=1.10 >*/
     QMI_UIM_CARD_APPLICATION_PERSONALIZATION_FEATURE_GW_NETWORK          = 0,
     QMI_UIM_CARD_APPLICATION_PERSONALIZATION_FEATURE_GW_NETWORK_SUBSET   = 1,
     QMI_UIM_CARD_APPLICATION_PERSONALIZATION_FEATURE_GW_SERVICE_PROVIDER = 2,
@@ -415,10 +344,53 @@ typedef enum {
     QMI_UIM_CARD_APPLICATION_PERSONALIZATION_FEATURE_UNKNOWN             = 11
 } QmiUimCardApplicationPersonalizationFeature;
 
+/*****************************************************************************/
+/* Helper enums for the 'QMI UIM Get Slot Status' request/response */
+
 /**
- * qmi_uim_card_application_personalization_feature_get_string:
+ * QmiUimPhysicalCardState:
+ * @QMI_UIM_PHYSICAL_CARD_STATE_UNKNOWN: Unknown.
+ * @QMI_UIM_PHYSICAL_CARD_STATE_ABSENT: Absent.
+ * @QMI_UIM_PHYSICAL_CARD_STATE_PRESENT: Present.
  *
- * Since: 1.10
+ * State of the physical card.
+ *
+ * Since: 1.26
  */
+typedef enum { /*< since=1.26 >*/
+    QMI_UIM_PHYSICAL_CARD_STATE_UNKNOWN = 0,
+    QMI_UIM_PHYSICAL_CARD_STATE_ABSENT  = 1,
+    QMI_UIM_PHYSICAL_CARD_STATE_PRESENT = 2,
+} QmiUimPhysicalCardState;
+
+/**
+ * QmiUimSlotState:
+ * @QMI_UIM_SLOT_STATE_INACTIVE: Inactive.
+ * @QMI_UIM_SLOT_STATE_ACTIVE: Active.
+ *
+ * State of the slot.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    QMI_UIM_SLOT_STATE_INACTIVE = 0,
+    QMI_UIM_SLOT_STATE_ACTIVE   = 1,
+} QmiUimSlotState;
+
+/**
+ * QmiUimCardProtocol:
+ * @QMI_UIM_CARD_PROTOCOL_UNKNOWN: Unknown.
+ * @QMI_UIM_CARD_PROTOCOL_ICC: ICC protocol.
+ * @QMI_UIM_CARD_PROTOCOL_UICC: UICC protocol.
+ *
+ * Protocol for the card.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    QMI_UIM_CARD_PROTOCOL_UNKNOWN = 0,
+    QMI_UIM_CARD_PROTOCOL_ICC     = 1,
+    QMI_UIM_CARD_PROTOCOL_UICC    = 2,
+} QmiUimCardProtocol;
 
 #endif /* _LIBQMI_GLIB_QMI_ENUMS_UIM_H_ */
