@@ -24,7 +24,7 @@
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301 USA.
  *
- * Copyright (C) 2012-2017 Aleksander Morgado <aleksander@aleksander.es>
+ * Copyright (C) 2012-2019 Aleksander Morgado <aleksander@aleksander.es>
  */
 
 #include <glib.h>
@@ -34,7 +34,7 @@
 #include <endian.h>
 
 #include "qmi-message.h"
-#include "qmi-utils.h"
+#include "qmi-utils-private.h"
 #include "qmi-enums-private.h"
 #include "qmi-enum-types-private.h"
 #include "qmi-enum-types.h"
@@ -55,6 +55,8 @@
 #include "qmi-loc.h"
 #include "qmi-qos.h"
 #include "qmi-gas.h"
+#include "qmi-gms.h"
+#include "qmi-dsd.h"
 
 #define PACKED __attribute__((packed))
 
@@ -519,10 +521,10 @@ qmi_message_response_new (QmiMessage       *request,
         ((struct full_message *)(((GByteArray *)response)->data))->qmi.service.header.flags |= QMI_SERVICE_FLAG_RESPONSE;
 
     /* Add result TLV, should never fail */
-    g_assert ((tlv_offset = qmi_message_tlv_write_init (response, 0x02, NULL)) > 0);
-    g_assert (qmi_message_tlv_write_guint16 (response, QMI_ENDIAN_LITTLE, (error != QMI_PROTOCOL_ERROR_NONE), NULL));
-    g_assert (qmi_message_tlv_write_guint16 (response, QMI_ENDIAN_LITTLE, error, NULL));
-    g_assert (qmi_message_tlv_write_complete (response, tlv_offset, NULL));
+    tlv_offset = qmi_message_tlv_write_init (response, 0x02, NULL);
+    qmi_message_tlv_write_guint16 (response, QMI_ENDIAN_LITTLE, (error != QMI_PROTOCOL_ERROR_NONE), NULL);
+    qmi_message_tlv_write_guint16 (response, QMI_ENDIAN_LITTLE, error, NULL);
+    qmi_message_tlv_write_complete (response, tlv_offset, NULL);
 
     /* We shouldn't create invalid response messages */
     g_assert (message_check (response, NULL));
@@ -594,7 +596,7 @@ tlv_error_if_write_overflow (QmiMessage  *self,
 
 static struct tlv *
 tlv_get_header (QmiMessage *self,
-                gssize      init_offset)
+                gsize       init_offset)
 {
     g_assert (init_offset <= self->len);
     return (struct tlv *)(&self->data[init_offset]);
@@ -1627,50 +1629,125 @@ qmi_message_get_printable_full (QmiMessage        *self,
     contents = NULL;
     switch (qmi_message_get_service (self)) {
     case QMI_SERVICE_CTL:
+#if defined HAVE_QMI_SERVICE_CTL
         contents = __qmi_message_ctl_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_DMS:
+#if defined HAVE_QMI_SERVICE_DMS
         contents = __qmi_message_dms_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_WDS:
+#if defined HAVE_QMI_SERVICE_WDS
         contents = __qmi_message_wds_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_NAS:
+#if defined HAVE_QMI_SERVICE_NAS
         contents = __qmi_message_nas_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_WMS:
+#if defined HAVE_QMI_SERVICE_WMS
         contents = __qmi_message_wms_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_PDC:
+#if defined HAVE_QMI_SERVICE_PDC
         contents = __qmi_message_pdc_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_PDS:
+#if defined HAVE_QMI_SERVICE_PDS
         contents = __qmi_message_pds_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_PBM:
+#if defined HAVE_QMI_SERVICE_PBM
         contents = __qmi_message_pbm_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_UIM:
+#if defined HAVE_QMI_SERVICE_UIM
         contents = __qmi_message_uim_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_OMA:
+#if defined HAVE_QMI_SERVICE_OMA
         contents = __qmi_message_oma_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_GAS:
+#if defined HAVE_QMI_SERVICE_GAS
         contents = __qmi_message_gas_get_printable (self, context, line_prefix);
+#endif
+        break;
+    case QMI_SERVICE_GMS:
+#if defined HAVE_QMI_SERVICE_GMS
+        contents = __qmi_message_gms_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_WDA:
+#if defined HAVE_QMI_SERVICE_WDA
         contents = __qmi_message_wda_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_VOICE:
+#if defined HAVE_QMI_SERVICE_VOICE
         contents = __qmi_message_voice_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_LOC:
+#if defined HAVE_QMI_SERVICE_LOC
         contents = __qmi_message_loc_get_printable (self, context, line_prefix);
+#endif
         break;
     case QMI_SERVICE_QOS:
+#if defined HAVE_QMI_SERVICE_QOS
         contents = __qmi_message_qos_get_printable (self, context, line_prefix);
+#endif
         break;
+    case QMI_SERVICE_DSD:
+#if defined HAVE_QMI_SERVICE_DSD
+        contents = __qmi_message_dsd_get_printable (self, context, line_prefix);
+#endif
+        break;
+
+    case QMI_SERVICE_UNKNOWN:
+        g_assert_not_reached ();
+
+    case QMI_SERVICE_AUTH:
+    case QMI_SERVICE_AT:
+    case QMI_SERVICE_CAT2:
+    case QMI_SERVICE_QCHAT:
+    case QMI_SERVICE_RMTFS:
+    case QMI_SERVICE_TEST:
+    case QMI_SERVICE_SAR:
+    case QMI_SERVICE_IMS:
+    case QMI_SERVICE_ADC:
+    case QMI_SERVICE_CSD:
+    case QMI_SERVICE_MFS:
+    case QMI_SERVICE_TIME:
+    case QMI_SERVICE_TS:
+    case QMI_SERVICE_TMD:
+    case QMI_SERVICE_SAP:
+    case QMI_SERVICE_TSYNC:
+    case QMI_SERVICE_RFSA:
+    case QMI_SERVICE_CSVT:
+    case QMI_SERVICE_QCMAP:
+    case QMI_SERVICE_IMSP:
+    case QMI_SERVICE_IMSVT:
+    case QMI_SERVICE_IMSA:
+    case QMI_SERVICE_COEX:
+    case QMI_SERVICE_STX:
+    case QMI_SERVICE_BIT:
+    case QMI_SERVICE_IMSRTP:
+    case QMI_SERVICE_RFRPE:
+    case QMI_SERVICE_SSCTL:
+    case QMI_SERVICE_CAT:
+    case QMI_SERVICE_RMS:
+    case QMI_SERVICE_FOTA:
     default:
         break;
     }
@@ -1683,76 +1760,73 @@ qmi_message_get_printable_full (QmiMessage        *self,
     return g_string_free (printable, FALSE);
 }
 
-gboolean
-qmi_message_get_version_introduced_full (QmiMessage        *self,
-                                         QmiMessageContext *context,
-                                         guint             *major,
-                                         guint             *minor)
-{
-    switch (qmi_message_get_service (self)) {
-    case QMI_SERVICE_CTL:
-        /* For CTL service, we'll assume the minimum one */
-        *major = 0;
-        *minor = 0;
-        return TRUE;
-
-    case QMI_SERVICE_DMS:
-        return __qmi_message_dms_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_WDS:
-        return __qmi_message_wds_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_NAS:
-        return __qmi_message_nas_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_WMS:
-        return __qmi_message_wms_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_PDS:
-        return __qmi_message_pds_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_PBM:
-        return __qmi_message_pbm_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_UIM:
-        return __qmi_message_uim_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_OMA:
-        return __qmi_message_oma_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_GAS:
-        return __qmi_message_oma_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_WDA:
-        return __qmi_message_wda_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_LOC:
-        return __qmi_message_loc_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_VOICE:
-        return __qmi_message_voice_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_PDC:
-        return __qmi_message_pdc_get_version_introduced (self, context, major, minor);
-
-    case QMI_SERVICE_QOS:
-        return __qmi_message_qos_get_version_introduced (self, context, major, minor);
-
-    default:
-        /* For the still unsupported services, cannot do anything */
-        return FALSE;
-    }
-}
-
 gboolean
 __qmi_message_is_abortable (QmiMessage        *self,
                             QmiMessageContext *context)
 {
     switch (qmi_message_get_service (self)) {
     case QMI_SERVICE_WDS:
+#if defined HAVE_QMI_SERVICE_WDS
         return __qmi_message_wds_is_abortable (self, context);
+#else
+        return FALSE;
+#endif
     case QMI_SERVICE_NAS:
+#if defined HAVE_QMI_SERVICE_NAS
         return __qmi_message_nas_is_abortable (self, context);
+#else
+        return FALSE;
+#endif
+
+    case QMI_SERVICE_UNKNOWN:
+        g_assert_not_reached ();
+
+    case QMI_SERVICE_CTL:
+    case QMI_SERVICE_DMS:
+    case QMI_SERVICE_WMS:
+    case QMI_SERVICE_PDS:
+    case QMI_SERVICE_PBM:
+    case QMI_SERVICE_UIM:
+    case QMI_SERVICE_OMA:
+    case QMI_SERVICE_GAS:
+    case QMI_SERVICE_WDA:
+    case QMI_SERVICE_LOC:
+    case QMI_SERVICE_AUTH:
+    case QMI_SERVICE_AT:
+    case QMI_SERVICE_CAT2:
+    case QMI_SERVICE_QCHAT:
+    case QMI_SERVICE_RMTFS:
+    case QMI_SERVICE_TEST:
+    case QMI_SERVICE_SAR:
+    case QMI_SERVICE_IMS:
+    case QMI_SERVICE_ADC:
+    case QMI_SERVICE_CSD:
+    case QMI_SERVICE_MFS:
+    case QMI_SERVICE_TIME:
+    case QMI_SERVICE_TS:
+    case QMI_SERVICE_TMD:
+    case QMI_SERVICE_SAP:
+    case QMI_SERVICE_TSYNC:
+    case QMI_SERVICE_RFSA:
+    case QMI_SERVICE_CSVT:
+    case QMI_SERVICE_QCMAP:
+    case QMI_SERVICE_IMSP:
+    case QMI_SERVICE_IMSVT:
+    case QMI_SERVICE_IMSA:
+    case QMI_SERVICE_COEX:
+    case QMI_SERVICE_STX:
+    case QMI_SERVICE_BIT:
+    case QMI_SERVICE_IMSRTP:
+    case QMI_SERVICE_RFRPE:
+    case QMI_SERVICE_SSCTL:
+    case QMI_SERVICE_CAT:
+    case QMI_SERVICE_RMS:
+    case QMI_SERVICE_FOTA:
+    case QMI_SERVICE_GMS:
+    case QMI_SERVICE_VOICE:
+    case QMI_SERVICE_PDC:
+    case QMI_SERVICE_DSD:
+    case QMI_SERVICE_QOS:
     default:
         return FALSE;
     }
