@@ -226,7 +226,7 @@ disown_not_released_clients (QmiProxy *self,
 {
     guint i;
 
-    if (!client->qmi_client_info_array->len)
+    if (!client->qmi_client_info_array || !client->qmi_client_info_array->len)
         return;
 
     for (i = 0; i < client->qmi_client_info_array->len; i++) {
@@ -342,6 +342,9 @@ indication_cb (QmiDevice *device,
 {
     guint i;
 
+    if (!client->qmi_client_info_array)
+        return;
+
     for (i = 0; i < client->qmi_client_info_array->len; i++) {
         QmiClientInfo *info;
 
@@ -572,6 +575,9 @@ qmi_client_info_array_lookup_cid (GArray     *array,
 {
     guint i;
 
+    if (!array)
+        return -1;
+
     for (i = 0; i < array->len; i++) {
         QmiClientInfo *item;
 
