@@ -33,6 +33,8 @@
 #include "qmicli.h"
 #include "qmicli-helpers.h"
 
+#if defined HAVE_QMI_SERVICE_WDA
+
 #define QMI_WDA_DL_AGGREGATION_PROTOCOL_MAX_DATAGRAMS_UNDEFINED 0xFFFFFFFF
 #define QMI_WDA_DL_AGGREGATION_PROTOCOL_MAX_DATAGRAM_SIZE_UNDEFINED 0xFFFFFFFF
 #define QMI_WDA_ENDPOINT_INTERFACE_NUMBER_UNDEFINED -1
@@ -46,24 +48,47 @@ typedef struct {
 static Context *ctx;
 
 /* Options */
-static gchar *set_data_format_str;
-static gboolean get_data_format_flag;
-static gboolean get_supported_messages_flag;
-static gboolean noop_flag;
+static gchar    *set_data_format_str;
+static gchar    *get_data_format_str;
+static gboolean  get_data_format_flag;
+static gboolean  get_supported_messages_flag;
+static gboolean  noop_flag;
+
+#if defined HAVE_QMI_MESSAGE_WDA_GET_DATA_FORMAT
+
+static gboolean
+parse_get_data_format (const gchar  *option_name,
+                       const gchar  *value,
+                       gpointer      data,
+                       GError      **error)
+{
+    get_data_format_flag = TRUE;
+    if (value && value[0])
+        get_data_format_str = g_strdup (value);
+    return TRUE;
+}
+
+#endif
 
 static GOptionEntry entries[] = {
+#if defined HAVE_QMI_MESSAGE_WDA_SET_DATA_FORMAT
     { "wda-set-data-format", 0, 0, G_OPTION_ARG_STRING, &set_data_format_str,
       "Set data format (allowed keys: link-layer-protocol (802-3|raw-ip), ul-protocol (tlp|qc-ncm|mbim|rndis|qmap), dl-protocol (tlp|qc-ncm|mbim|rndis|qmap), dl-datagram-max-size, dl-max-datagrams, ep-type (undefined|hsusb), ep-iface-number)",
       "[\"key=value,...\"]"
     },
-    { "wda-get-data-format", 0, 0, G_OPTION_ARG_NONE, &get_data_format_flag,
-      "Get data format",
-      NULL
+#endif
+#if defined HAVE_QMI_MESSAGE_WDA_GET_DATA_FORMAT
+    { "wda-get-data-format", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, parse_get_data_format,
+      "Get data format (allowed keys: ep-type (undefined|hsusb), ep-iface-number); also allows empty key list",
+      "[\"key=value,...\"]"
     },
+#endif
+#if defined HAVE_QMI_MESSAGE_WDA_GET_SUPPORTED_MESSAGES
     { "wda-get-supported-messages", 0, 0, G_OPTION_ARG_NONE, &get_supported_messages_flag,
       "Get supported messages",
       NULL
     },
+#endif
     { "wda-noop", 0, 0, G_OPTION_ARG_NONE, &noop_flag,
       "Just allocate or release a WDA client. Use with `--client-no-release-cid' and/or `--client-cid'",
       NULL
@@ -77,7 +102,7 @@ qmicli_wda_get_option_group (void)
     GOptionGroup *group;
 
     group = g_option_group_new ("wda",
-                                "WDA options",
+                                "WDA options:",
                                 "Show Wireless Data Administrative options",
                                 NULL,
                                 NULL);
@@ -137,6 +162,104 @@ noop_cb (gpointer unused)
     return FALSE;
 }
 
+#if defined HAVE_QMI_MESSAGE_WDA_GET_DATA_FORMAT
+
+typedef struct {
+    QmiDataEndpointType endpoint_type;
+    gint                endpoint_iface_number;
+} GetDataFormatProperties;
+
+static gboolean
+get_data_format_properties_handle (const gchar  *key,
+                                   const gchar  *value,
+                                   GError      **error,
+                                   gpointer      user_data)
+{
+    GetDataFormatProperties *props = (GetDataFormatProperties *)user_data;
+
+    if (!value || !value[0]) {
+        g_set_error (error,
+                     QMI_CORE_ERROR,
+                     QMI_CORE_ERROR_FAILED,
+                     "key '%s' requires a value",
+                     key);
+        return FALSE;
+    }
+
+    if (g_ascii_strcasecmp (key, "ep-type") == 0) {
+        if (!qmicli_read_data_endpoint_type_from_string (value, &(props->endpoint_type))) {
+            g_set_error (error,
+                         QMI_CORE_ERROR,
+                         QMI_CORE_ERROR_FAILED,
+                         "Unrecognized Endpoint Type '%s'",
+                         value);
+            return FALSE;
+        }
+        return TRUE;
+    }
+
+    if (g_ascii_strcasecmp (key, "ep-iface-number") == 0) {
+        props->endpoint_iface_number = atoi (value);
+        return TRUE;
+    }
+
+    g_set_error (error,
+                 QMI_CORE_ERROR,
+                 QMI_CORE_ERROR_FAILED,
+                 "Unrecognized option '%s'",
+                 key);
+    return FALSE;
+}
+
+static QmiMessageWdaGetDataFormatInput *
+get_data_format_input_create (const gchar *str)
+{
+    g_autoptr(QmiMessageWdaGetDataFormatInput) input = NULL;
+    g_autoptr(GError) error = NULL;
+    GetDataFormatProperties props = {
+        .endpoint_type         = QMI_DATA_ENDPOINT_TYPE_UNDEFINED,
+        .endpoint_iface_number = QMI_WDA_ENDPOINT_INTERFACE_NUMBER_UNDEFINED,
+    };
+
+    input = qmi_message_wda_get_data_format_input_new ();
+
+    if (!qmicli_parse_key_value_string (str,
+                                        &error,
+                                        get_data_format_properties_handle,
+                                        &props)) {
+        g_printerr ("error: could not parse input string '%s'\n", error->message);
+        return NULL;
+    }
+
+    if ((props.endpoint_type == QMI_DATA_ENDPOINT_TYPE_UNDEFINED) ^
+        (props.endpoint_iface_number == QMI_WDA_ENDPOINT_INTERFACE_NUMBER_UNDEFINED)) {
+        g_printerr ("error: endpoint type and interface number must be both set or both unset\n");
+        return NULL;
+    }
+
+    if (props.endpoint_type != QMI_DATA_ENDPOINT_TYPE_UNDEFINED &&
+        !qmi_message_wda_get_data_format_input_set_endpoint_info (
+            input,
+            props.endpoint_type,
+            props.endpoint_iface_number,
+            &error)) {
+        g_printerr ("error: could not set peripheral endpoint id: %s\n", error->message);
+        return NULL;
+    }
+
+    if (props.endpoint_iface_number != QMI_WDA_ENDPOINT_INTERFACE_NUMBER_UNDEFINED &&
+        !qmi_message_wda_get_data_format_input_set_endpoint_info (
+            input,
+            QMI_DATA_ENDPOINT_TYPE_HSUSB,
+            props.endpoint_iface_number,
+            &error)) {
+        g_printerr ("error: could not set peripheral endpoint id: %s\n", error->message);
+        return NULL;
+    }
+
+    return g_steal_pointer (&input);
+}
+
 static void
 get_data_format_ready (QmiClientWda *client,
                        GAsyncResult *res)
@@ -218,6 +341,10 @@ get_data_format_ready (QmiClientWda *client,
     operation_shutdown (TRUE);
 }
 
+#endif /* HAVE_QMI_MESSAGE_WDA_GET_DATA_FORMAT */
+
+#if defined HAVE_QMI_MESSAGE_WDA_SET_DATA_FORMAT
+
 static void
 set_data_format_ready (QmiClientWda *client,
                        GAsyncResult *res)
@@ -299,7 +426,6 @@ set_data_format_ready (QmiClientWda *client,
     operation_shutdown (TRUE);
 }
 
-
 typedef struct {
     QmiWdaLinkLayerProtocol link_layer_protocol;
     QmiWdaDataAggregationProtocol ul_protocol;
@@ -307,7 +433,7 @@ typedef struct {
     guint32 dl_datagram_max_size;
     guint32 dl_max_datagrams;
     QmiDataEndpointType endpoint_type;
-    guint32 endpoint_iface_number;
+    gint endpoint_iface_number;
 } SetDataFormatProperties;
 
 
@@ -534,6 +660,10 @@ error_out:
     return NULL;
 }
 
+#endif /* HAVE_QMI_MESSAGE_WDA_SET_DATA_FORMAT */
+
+#if defined HAVE_QMI_MESSAGE_WDA_GET_SUPPORTED_MESSAGES
+
 static void
 get_supported_messages_ready (QmiClientWda *client,
                               GAsyncResult *res)
@@ -572,6 +702,8 @@ get_supported_messages_ready (QmiClientWda *client,
     operation_shutdown (TRUE);
 }
 
+#endif /* HAVE_QMI_MESSAGE_WDA_GET_SUPPORTED_MESSAGES */
+
 void
 qmicli_wda_run (QmiDevice *device,
                 QmiClientWda *client,
@@ -583,7 +715,7 @@ qmicli_wda_run (QmiDevice *device,
     ctx->client = g_object_ref (client);
     ctx->cancellable = g_object_ref (cancellable);
 
-    /* Request to set data format? */
+#if defined HAVE_QMI_MESSAGE_WDA_SET_DATA_FORMAT
     if (set_data_format_str) {
         QmiMessageWdaSetDataFormatInput *input;
 
@@ -603,20 +735,32 @@ qmicli_wda_run (QmiDevice *device,
         qmi_message_wda_set_data_format_input_unref (input);
         return;
     }
+#endif
 
-    /* Request to read data format? */
+#if defined HAVE_QMI_MESSAGE_WDA_GET_DATA_FORMAT
     if (get_data_format_flag) {
+        g_autoptr(QmiMessageWdaGetDataFormatInput) input = NULL;
+
+        if (get_data_format_str) {
+            input = get_data_format_input_create (get_data_format_str);
+            if (!input) {
+                operation_shutdown (FALSE);
+                return;
+            }
+        }
+
         g_debug ("Asynchronously getting data format...");
         qmi_client_wda_get_data_format (ctx->client,
-                                        NULL,
+                                        input,
                                         10,
                                         ctx->cancellable,
                                         (GAsyncReadyCallback)get_data_format_ready,
                                         NULL);
         return;
     }
+#endif
 
-    /* Request to list supported messages? */
+#if defined HAVE_QMI_MESSAGE_WDA_GET_SUPPORTED_MESSAGES
     if (get_supported_messages_flag) {
         g_debug ("Asynchronously getting supported WDA messages...");
         qmi_client_wda_get_supported_messages (ctx->client,
@@ -627,6 +771,7 @@ qmicli_wda_run (QmiDevice *device,
                                                NULL);
         return;
     }
+#endif
 
     /* Just client allocate/release? */
     if (noop_flag) {
@@ -636,3 +781,5 @@ qmicli_wda_run (QmiDevice *device,
 
     g_warn_if_reached ();
 }
+
+#endif /* HAVE_QMI_SERVICE_WDA */
